ooi: OpenStack OCCI Interface
=============================

ooi is an implementation the Open Grid Forum's
[Open Cloud Computing Interface (OCCI)](http://www.occi-wg.org)
for [OpenStack](http://www.openstack.org).

* [About OOI](README.md)
* [Documentation (online)](http://ooi.readthedocs.io/en/stable/)
